@@ -15,17 +15,18 @@
 #'   entries equivalent to 0.02 logmar
 #' @param noplus ignoring plus/minus entries and just returning the
 #'     snellen fraction. This overrides the smallstep argument.
+#' @param quali_values define your own values for qualitative entries (see details)
 #' @name va
 #' @section VA conversion:
 #' - **logMAR to ETDRS**: logMAR rounded to the first digit and converted with
 #' the visual acuity chart (see section VA chart)
 #' - **Snellen to logMAR**: logMAR = -1 * log10(snellen_frac)
 #' - **Snellen to ETDRS**: ETDRS = 85 + 50 * log10(snellen_frac)
-#' \doi{10.1097/iae.0b013e3181d87e04}
+#' Gregori et al. DOI: 10.1097/iae.0b013e3181d87e04
 #' - **ETDRS to logMAR**: logMAR = -0.02 * etdrs + 1.7
-#' Beck et al. \doi{10.1016/s0002-9394(02)01825-1}
+#'  Beck et al. DOI: 10.1016/s0002-9394(02)01825-1
 #' - **Hand movements and counting fingers** are converted following
-#' Schulze-Bonsel et al. - https://doi.org/10.1167/iovs.05-0981
+#' Schulze-Bonsel et al. DOI: 10.1167/iovs.05-0981
 #' - **(No) light perception** are converted following the suggestions by
 #' [Michael Bach](https://michaelbach.de/sci/acuity.html)
 #' @section Qualitative visual acuity entries:
@@ -35,8 +36,21 @@
 #' ETDRS letter, in order to keep it as a measurement (not: NA). It is very
 #' difficult to justify a "negative" letter score in a test which only has
 #' a specific range (0-100).
+#' By default, `va` recognises the following values (case does not matter!)
 #'
-#' - **To Snellen**:
+#' - No light perception := c("nlp", "no light perception", "no light", "no perception of light", "npl"),
+#' - Light perception: = c("lp", "light perception", "perception of light", "pl"),
+#' - Hand movements: = c("hm",  "handmotion", "hand movement", "hand movements"),
+#' - Counting fingers: = c("cf", "counting finger", "counting fingers", "finger count", "count fingers")
+#'
+#' @section Custom values for qualitative entries:
+#' To define your own values for qualitative entries, you need to
+#' pass a names list with names c("cf", "hm", "nlp", "lp") - in that order.
+#' It accepts only values that can be reasonably converted into numeric values
+#' and it converts only to logMAR.
+#' If you want to convert to a different notation, you will need to
+#' call va() a second time.
+#' @section Converting to Snellen:
 #' Although there seems to be no good statistical reason to convert
 #' back to Snellen, it is a very natural thing to eye specialists to think
 #' in Snellen. A conversion to snellen gives a good gauge of how the visual
@@ -46,12 +60,13 @@
 #' Therefore, Snellen matching the nearest ETDRS and logMAR value in
 #' the VA chart are used.
 #' @section VA chart:
-#' You can find with eye:::va_chart.
+#' You can find the chart with `eye:::va_chart`.
 #' This chart and VA conversion formulas are based on charts in
-#' Holladay et al.\doi{10.1016/j.jcrs.2004.01.014}, Beck et al.
-#' \doi{10.1016/s0002-9394(02)01825-1}{Beck et al.}, and
-#' Gregori et al.\doi{10.1097/iae.0b013e3181d87e04}.
-#' The etdrs values for NLP and PL are deliberately set at those values because
+#' Holladay et al. DOI: 10.1016/j.jcrs.2004.01.014,
+#' Beck et al. DOI: 10.1016/s0002-9394(02)01825-1, and
+#' Gregori et al. DOI: 10.1097/iae.0b013e3181d87e04.
+#'
+#' The ETDRS values for NLP and PL are deliberately set at those values because
 #' they are unlikely to happen by chance as a wrong entry (and as integers),
 #' and it has internal reasons that make conversion easier.
 #' @section Accepted VA formats / Plausibility checks:
@@ -83,42 +98,42 @@
 #' 1. `NA` is assigned to strings such as "." or "", "n/a" or "   "
 #' 1. notation for qualitative entries is simplified.
 #' @section VA classes:
-#' convertVA returns a vector of three classes:
+#' Under the hood, `convertVA` returns a vector that has three classes:
 #'   1. `va`
 #'   1. One of snellen, snellendec, logmar, etdrs or quali.
-#'   1. Either of `character` (for Snellen, snellendec, and qualitative),
+#'   1. Either of `character` (for Snellen, Snellen decimal, and qualitative),
 #'       `numeric` (for logMAR), or `integer` (for ETDRS).
 #' @return vector of `va` class. See also "VA classes"
 #' @family Ophthalmic functions
 #' @family VA converter
 #' @family VA cleaner
 #' @examples
-#' ## will automatically detect VA class and convert to logMAR by default
-#' ## ETDRS letters
-#' x <- c(23, 56, 74, 58)
+#' ## calling va without specifying "to" will clean visual acuity entries
+#' ## without conversion into another notation. Weird entries will be
+#' ## replaced by a missing value that R recognises as such
+#' x <- c(23, "", NA, "N/A", "Not measured", "20/50", 74, 58)
 #' va(x)
 #'
 #' ## ... or convert to snellen
 #' va(x, to = "snellen")
 #'
-#' ## snellen, mixed with categories. Also dealing with those "plus/minus" entries
+#' ## Dealing with those "plus/minus" entries, and qualitative values such as "HM"
 #' va(c("NLP", "NPL", "PL", "LP", "HM", "CF", "6/60", "20/200", "6/9",
-#'  "20/40", "20/40+3", "20/50-2"))
+#'  "20/40", "20/40+3", "20/50-2"), to = "snellen")
 #'
 #' ## A mix of notations is also possible
 #' x <- c("NLP", "0.8", "34", "3/60", "2/200", "20/40+3", "20/50-2")
-#' va(x)
+#' va(x, to = "snellen")
 #'
 #' ## Any fraction is possible, and empty values
+#' ## change Snellen type to meter with type = "m"
 #' x <- c("CF", "3/60", "2/200", "", "20/40+3", ".", "      ")
-#' va(x)
+#' va(x, to = "snellen", type = "m")
 #'
-#' ## but this not any fraction when converting from one class to the other
-#' x <- c("3/60", "2/200", "6/60", "20/200", "6/9")
-#' va(x, to="snellen", type = "m")
 #' @export
 va <- function(x, from = NULL, to = NULL, type = "ft",
-               smallstep = FALSE, noplus = FALSE) {
+               smallstep = FALSE, noplus = FALSE,
+               quali_values = NULL) {
   if (!is.atomic(x)) {
     stop("x must be atomic", call. = FALSE)
   }
@@ -140,11 +155,12 @@ va <- function(x, from = NULL, to = NULL, type = "ft",
     }
   }
   if (inherits(x, "va")) {
-    conVA <- convertVA(x, to = to, type = type,
-                       smallstep = smallstep, noplus = noplus
+    conVA <- convertVA(x,
+      to = to, type = type,
+      smallstep = smallstep, noplus = noplus
     )
-      return(conVA)
-    } else {
+    return(conVA)
+  } else {
     x_clean <- clean_va(x, message = FALSE)
     guess_va <- which_va(x_clean)
 
@@ -178,48 +194,74 @@ va <- function(x, from = NULL, to = NULL, type = "ft",
         va_class <- guess_va[1]
       }
     }
-    }
+  }
   class(x_clean) <- c(va_class, class(x_clean))
 
-  x_noquali <- convertQuali(x_clean, to_class = va_class)
-
+  ## standard without custom qualis
+  if(is.null(quali_values)){
+  x_noquali <- convertQuali(x_clean,
+    to_class = va_class
+  )
   class(x_noquali) <- va_class
-
   x_plausible <- checkVA(x_noquali)
   newNA <- as.logical(is.na(x_plausible) - is.na(x))
   introduceNA(x, newNA)
 
   x_final <- convertVA(
-    x_plausible, to = to, type = type,
-    smallstep = smallstep, noplus = noplus
+    x_plausible,
+    to = to,
+    type = type,
+    smallstep = smallstep,
+    noplus = noplus
   )
+  } else {
+    x_noquali <- convertQuali_custom(x_clean,
+                        to_class = va_class,
+                        to = to,
+                        quali_values = quali_values)
+    class(x_noquali) <- va_class
+    x_plausible <- checkVA(x_clean)
+    ## converting non_quali values to logMAR
+    x_to_logmar <- convertVA(
+      x_plausible,
+      to = to,
+      type = type,
+      smallstep = smallstep,
+      noplus = noplus
+    )
+
+    x_final <- ifelse(is.na(x_to_logmar), x_noquali, x_to_logmar)
+    newNA <- as.logical(is.na(x_final) - is.na(x))
+    introduceNA(x, newNA)
+
+  }
   x_final
 }
-
 #' VA classes
 #' @name va_mixed
 #' @param x vector with mixed VA entries
 #' @param to to which notation to be converted
-#' @param possible which possible VA notations - and the precedence given,
-#'     see details
+#' @param possible possible VA notations. The order defines which class
+#' will be prioritised if a value can be from more than one class, see details.
+#' Default = c("snellen", "etdrs", "logmar", "quali")
 #' @description va_mixed is a wrapper around [va] on all possible VA notations.
 #'   By default, c("snellen", "etdrs", "logmar", "snellendec") will be converted -
 #'   in that order! For tricky cases see details and examples. Note
-#'   that va_mixed will not give nice messages which values are transformed
-#'   from which notation, and which values were replaced with NA.
+#'   that va_mixed will not notify you from which notation the values
+#'   were transformed, nor if values were replaced with NA.
 #' @details Mixed entries are challenging, but unfortunately seem to occur in
 #'   real life data. It will be fairly individual what you have in yours, but
 #'   it should hopefully not happen that you have *all* possible notations.
 #'   Snellen fractions are usually not challenging because they contain a "/",
 #'   thus are easy to recognize.
 #'
-#'   **Most problematic are values between 0 and 3**,
+#'   **Values between 0 and 3 are most problematic**,
 #'   in particular full integers - this can be EDTRS, snellen decimal notation
-#'   or logmar. If your data doesn't have snellen decimal notation,
-#'   specify this with "possible", e.g. with
-#'   `possible = c("snellen", "etdrs", "logmar")`. If you know that you don't
-#'   have any ETDRS value less than 4, you can safely give precedence to logmar
-#'   instead, like this: `possible = c("snellen", "logmar", "etdrs")`
+#'   or logmar. By default, snellen decimal are not recognized, but you can
+#'   specify this with the "possible" argument.
+#'   Or, if you know that you don't have any ETDRS value less than 4,
+#'   you can safely give precedence to logmar instead, like this:
+#'   `possible = c("snellen", "logmar", "etdrs")`
 #'   @examples
 #'   # awfully mixed notation!! (and note the wrong -1 value)
 #'   x <- c(NA, "nlp", 1:2, 1.1, -1, "20/40", "4/6", "6/1000", 34)
@@ -234,18 +276,23 @@ va <- function(x, from = NULL, to = NULL, type = "ft",
 #' @family Ophthalmic functions
 #' @family VA converter
 #' @export
-va_mixed <- function(x, to, possible) {
-  if (missing(possible)) {
-    possible <- VAclasses[1:4]
-  } else {
+va_mixed <- function(x, to = "logmar",
+                     possible = c("snellen", "etdrs", "logmar", "quali")) {
     possible <- tolower(possible)
-  }
+
   a <- sapply(possible, function(vaclass) {
     suppressMessages(va(x, to = to, from = vaclass))
   })
-  apply(a, 1, function(z) z[!is.na(z)][1])
+    ## fixed somewhat annoying bug to not allow vector of length = 1
+  if(is.null(dim(a))) {
+    return(unname(a[!is.na(a)][1]))
+  } else {
+  return(apply(a, 1, function(z) z[!is.na(z)][1]))
+  }
 }
 
+
+
 #' VA classes
 #' @name VAclasses
 #' @keywords internal
